@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2016 Christian Geier et al.
+# Copyright (c) 2013-2017 Christian Geier et al.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -29,10 +29,9 @@ import datetime
 import os
 import os.path
 import itertools
-import math
 
-from vdirsyncer.storage.filesystem import FilesystemStorage
-from vdirsyncer.exceptions import AlreadyExistingError
+from .vdir import CollectionNotFoundError, AlreadyExistingError, Vdir, \
+    get_etag_from_file
 
 from . import backend
 from .event import Event
@@ -57,7 +56,7 @@ def create_directory(path):
 class CalendarCollection(object):
     """CalendarCollection allows access to various calendars stored in vdirs
 
-    all calendars are cached in an sqlitedb for perforamce reasons"""
+    all calendars are cached in an sqlitedb for performance reasons"""
 
     def __init__(self,
                  calendars=None,
@@ -82,7 +81,13 @@ class CalendarCollection(object):
                 file_ext = '.vcf'
             else:
                 raise ValueError('ctype must be either `calendar` or `birthdays`')
-            self._storages[name] = FilesystemStorage(calendar['path'], file_ext)
+            try:
+                self._storages[name] = Vdir(calendar['path'], file_ext)
+            except CollectionNotFoundError:
+                os.makedirs(calendar['path'])
+                logger.info('created non-existing vdir {}'.format(calendar['path']))
+                self._storages[name] = Vdir(calendar['path'], file_ext)
+
         self.hmethod = hmethod
         self.default_color = default_color
         self.multiple = multiple
@@ -91,6 +96,7 @@ class CalendarCollection(object):
         self._locale = locale
         self._backend = backend.SQLiteDb(
             calendars=self.names, db_path=dbpath, locale=self._locale)
+        self._last_ctags = dict()
         self.update_db()
 
     @property
@@ -125,11 +131,7 @@ class CalendarCollection(object):
                 'Calendar "{0}" is read-only and cannot be used as default'.format(default))
 
     def _local_ctag(self, calendar):
-        stat = os.stat(self._calendars[calendar]['path'])
-        mtime = getattr(stat, 'st_mtime_ns', None)
-        if mtime is None:
-            mtime = stat.st_mtime
-        return str(int(math.floor(mtime * 1e9)))
+        return get_etag_from_file(self._calendars[calendar]['path'])
 
     def _cover_event(self, event):
         event.color = self._calendars[event.calendar]['color']
@@ -159,23 +161,6 @@ class CalendarCollection(object):
 
         return itertools.chain(floating_events, localized_events)
 
-    def get_events_at(self, dtime=datetime.datetime.now()):
-        """get all events at datetime `dtime`
-
-        :type dtime: datetime.datetime
-        """
-        if dtime.tzinfo is None:
-            naive_dtime = dtime
-            local_dtime = self._locale['local_timezone'].localize(dtime)
-        else:
-            naive_dtime = dtime.replace(tzinfo=None)
-            local_dtime = dtime
-
-        floating_events = self._backend.get_floating_at(naive_dtime)
-        localized_events = self._backend.get_localized_at(local_dtime)
-        return (self._cover_event(event) for event in
-                itertools.chain(floating_events, localized_events))
-
     def update(self, event):
         """update `event` in vdir and db"""
         assert event.etag
@@ -205,7 +190,8 @@ class CalendarCollection(object):
     def new(self, event, collection=None):
         """save a new event to the vdir and the database
 
-        param event: the event that should be updated
+        param event: the event that should be updated, will get a new href and
+            etag properties
         type event: event.Event
         """
         calendar = collection if collection is not None else event.calendar
@@ -217,11 +203,11 @@ class CalendarCollection(object):
         with self._backend.at_once():
 
             try:
-                href, etag = self._storages[calendar].upload(event)
+                event.href, event.etag = self._storages[calendar].upload(event)
             except AlreadyExistingError as Error:
                 href = getattr(Error, 'existing_href', None)
                 raise DuplicateUid(href)
-            self._backend.update(event.raw, href, etag, calendar=calendar)
+            self._backend.update(event.raw, event.href, event.etag, calendar=calendar)
             self._backend.set_ctag(self._local_ctag(calendar), calendar=calendar)
 
     def delete(self, href, etag, calendar):
@@ -251,15 +237,45 @@ class CalendarCollection(object):
         should be called after every change to the vdir
         """
         for calendar in self._calendars:
-            if self._needs_update(calendar):
+            if self._needs_update(calendar, remember=True):
                 self._db_update(calendar)
 
-    def _needs_update(self, calendar):
+    def needs_update(self):
+        """Check if you need to call update_db.
+
+        This could either be the case because the vdirs were changed externally,
+        or another instance of khal updated the caching db already.
+        """
+        # TODO is it a good idea to munch both use cases together?
+        # in case another instance of khal has updated the db, we only need
+        # to get new events, but # update_db() takes potentially a long time to return
+        # but then the code (in ikhal's refresh code) would need to look like
+        # this:
+        #
+        # update_ui = False
+        # if collection.needs_update():
+        #   collection.update_db()
+        #   update_ui = True
+        # if collection.needs_refresh() or update_ui:
+        #   do_the_update()
+        #
+        # and the API would be made even uglier than it already is...
+        for calendar in self._calendars:
+            if self._needs_update(calendar) or \
+                    self._last_ctags[calendar] != self._local_ctag(calendar):
+                return True
+        return False
+
+    def _needs_update(self, calendar, remember=False):
         """checks if the db for the given calendar needs an update"""
-        return self._local_ctag(calendar) != self._backend.get_ctag(calendar)
+        local_ctag = self._local_ctag(calendar)
+        if remember:
+            self._last_ctags[calendar] = local_ctag
+        return local_ctag != self._backend.get_ctag(calendar)
 
     def _db_update(self, calendar):
         """implements the actual db update on a per calendar base"""
+        local_ctag = self._local_ctag(calendar)
         db_hrefs = set(href for href, etag in self._backend.list(calendar))
         storage_hrefs = set()
 
@@ -272,7 +288,8 @@ class CalendarCollection(object):
                     self._update_vevent(href, calendar=calendar)
             for href in db_hrefs - storage_hrefs:
                 self._backend.delete(href, calendar=calendar)
-            self._backend.set_ctag(self._local_ctag(calendar), calendar=calendar)
+            self._backend.set_ctag(local_ctag, calendar=calendar)
+            self._last_ctags[calendar] = local_ctag
 
     def _update_vevent(self, href, calendar):
         """should only be called during db_update, only updates the db,
