@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2016 Christian Geier et al.
+# Copyright (c) 2013-2017 Christian Geier et al.
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -28,6 +28,8 @@ import urwid
 import threading
 import time
 
+from .widgets import NColumns
+
 
 class Pane(urwid.WidgetWrap):
 
@@ -44,47 +46,51 @@ class Pane(urwid.WidgetWrap):
     def title(self):
         return self._title
 
+    def selectable(self):
+        """mark this widget as selectable"""
+        return True
+
     @property
     def description(self):
         return self._description
 
-    def get_keys(self):
-        """Return a description of the keystrokes recognized by this pane.
+    def dialog(self, text, buttons):
+        """Open a dialog box.
 
-        This method returns a list of tuples describing the keys
-        handled by a pane. This list is used to build a contextual
-        pane help. Each tuple is a pair of a list of keys and a
-        description.
-
-        The abstract pane returns the default keys handled by the
-        window. Panes which do not override these keys should extend
-        this list.
+        :param text: Text to appear as the body of the Dialog box
+        :type text: str
+        :param buttons: list of tuples button labels and functions to call
+            when the button is pressed
+        :type buttons: list(str, callable)
         """
-        return [(['up', 'down', 'pg.up', 'pg.down'],
-                 'navigate through the fields.'),
-                (['esc'], 'backtrack to the previous pane or exit.'),
-                (['F1', '?'], 'open this pane help.')]
+        lines = [urwid.Text(line) for line in text.splitlines()]
 
+        buttons = NColumns(
+            [urwid.Button(label, on_press=func) for label, func in buttons],
+            outermost=True,
+        )
+        lines.append(buttons)
+        content = urwid.LineBox(urwid.Pile(lines))
+        overlay = urwid.Overlay(content, self, 'center', ('relative', 70), ('relative', 70), None)
+        self.window.open(overlay)
 
-class HelpPane(Pane):
+    def keypress(self, size, key):
+        """Handle application-wide key strokes."""
+        if key in ['f1', '?']:
+            self.show_keybindings()
+        else:
+            return super().keypress(size, key)
 
-    """A contextual help screen."""
+    def show_keybindings(self):
+        lines = list()
+        lines.append('  Command              Keys')
+        lines.append('  =======              ====')
+        for command, keys in self._conf['keybindings'].items():
+            lines.append('  {:20} {}'.format(command, keys))
+        lines.append('')
+        lines.append("Press `Escape` to close this window")
 
-    def __init__(self, pane):
-        content = []
-        for key_list, description in pane.get_keys():
-            key_text = []
-            for key in key_list:
-                if key_text:
-                    key_text.append(', ')
-                key_text.append(('bright', key))
-            content.append(
-                urwid.Columns(
-                    [urwid.Padding(urwid.Text(key_text), left=10),
-                     urwid.Padding(urwid.Text(description), right=10)]))
-
-        Pane.__init__(self, urwid.ListBox(urwid.SimpleListWalker(content)),
-                      'Help')
+        self.dialog('\n'.join(lines), [])
 
 
 class Window(urwid.Frame):
@@ -100,20 +106,22 @@ class Window(urwid.Frame):
     to carry data between them.
     """
 
-    def __init__(self, footer=''):
+    def __init__(self, footer='', quit_keys=['q']):
         self._track = []
 
         header = urwid.AttrWrap(urwid.Text(''), 'header')
         footer = urwid.AttrWrap(urwid.Text(footer), 'footer')
-        urwid.Frame.__init__(self, urwid.Text(''),
-                             header=header,
-                             footer=footer)
+        urwid.Frame.__init__(
+            self, urwid.Text(''), header=header, footer=footer,
+        )
         self.update_header()
         self._original_w = None
+        self.quit_keys = quit_keys
 
         self._alert_daemon = AlertDaemon(self.update_header)
         self._alert_daemon.start()
         self.alert = self._alert_daemon.alert
+        self.loop = None
 
     def open(self, pane, callback=None):
         """Open a new pane.
@@ -143,12 +151,18 @@ class Window(urwid.Frame):
         else:
             raise urwid.ExitMainLoop()
 
+    def is_top_level(self):
+        """Is the current pane the top-level one?
+        """
+        return len(self._track) == 1
+
     def on_key_press(self, key):
         """Handle application-wide key strokes."""
-        if key in ['esc', 'q']:
+        if key in self.quit_keys:
             self.backtrack()
-        elif key in ['f1', '?']:
-            self.open(HelpPane(self._get_current_pane()))
+        elif key == 'esc' and not self.is_top_level():
+            self.backtrack()
+        return key
 
     def _update(self, pane):
         self.set_body(pane)
@@ -158,6 +172,13 @@ class Window(urwid.Frame):
         return self._track[-1][0] if self._track else None
 
     def update_header(self, alert=None):
+        """Update the Windows header line.
+
+        :param alert: additional text to show in header, additionally to
+            the current title. If `alert` is a tuple, the first entry must
+            be a valid palette entry
+        :type alert: str or (palette_entry, str)
+        """
         pane_title = getattr(self._get_current_pane(), 'title', None)
         text = []
 
