@@ -1,5 +1,6 @@
 import datetime
 import locale
+import platform
 
 import unicodedata
 import pytest
@@ -104,21 +105,21 @@ example_cz = [
     '\x1b[1mb\u0159e \x1b[0m27 28 29  1  2  3  4 ']
 
 example_gr = [
-    '\x1b[1m    δε τρ τε πε πα σα κυ \x1b[0m',
-    '\x1b[1mδεκ \x1b[0m28 29 30  1  2  3  4 ',
-    '     5  6  7  8  9 10 11 ',
-    '    \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
-    '    19 20 21 22 23 24 25 ',
-    '\x1b[1mιαν \x1b[0m26 27 28 29 30 31  1 ',
-    '     2  3  4  5  6  7  8 ',
-    '     9 10 11 12 13 14 15 ',
-    '    16 17 18 19 20 21 22 ',
-    '    23 24 25 26 27 28 29 ',
-    '\x1b[1mφεβ \x1b[0m30 31  1  2  3  4  5 ',
-    '     6  7  8  9 10 11 12 ',
-    '    13 14 15 16 17 18 19 ',
-    '    20 21 22 23 24 25 26 ',
-    '\x1b[1mμαρ \x1b[0m27 28 29  1  2  3  4 ']
+    '\x1b[1m     δε τρ τε πε πα σα κυ \x1b[0m',
+    '\x1b[1mδεκ  \x1b[0m28 29 30  1  2  3  4 ',
+    '      5  6  7  8  9 10 11 ',
+    '     \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
+    '     19 20 21 22 23 24 25 ',
+    '\x1b[1mιαν  \x1b[0m26 27 28 29 30 31  1 ',
+    '      2  3  4  5  6  7  8 ',
+    '      9 10 11 12 13 14 15 ',
+    '     16 17 18 19 20 21 22 ',
+    '     23 24 25 26 27 28 29 ',
+    '\x1b[1mφεβ  \x1b[0m30 31  1  2  3  4  5 ',
+    '      6  7  8  9 10 11 12 ',
+    '     13 14 15 16 17 18 19 ',
+    '     20 21 22 23 24 25 26 ',
+    '\x1b[1mμαρ  \x1b[0m27 28 29  1  2  3  4 ']
 
 example_de = [
     '\x1b[1m    Mo Di Mi Do Fr Sa So \x1b[0m',
@@ -138,56 +139,84 @@ example_de = [
     '\x1b[1mMär \x1b[0m27 28 29  1  2  3  4 ']
 
 example_de_freebsd = [
-    '\x1b[1m    Mo Di Mi Do Fr Sa So \x1b[0m',
-    '\x1b[1mDez.\x1b[0m28 29 30  1  2  3  4 ',
-    '     5  6  7  8  9 10 11 ',
-    '    \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
-    '    19 20 21 22 23 24 25 ',
-    '\x1b[1mJan.\x1b[0m26 27 28 29 30 31  1 ',
-    '     2  3  4  5  6  7  8 ',
-    '     9 10 11 12 13 14 15 ',
-    '    16 17 18 19 20 21 22 ',
-    '    23 24 25 26 27 28 29 ',
-    '\x1b[1mFeb.\x1b[0m30 31  1  2  3  4  5 ',
-    '     6  7  8  9 10 11 12 ',
-    '    13 14 15 16 17 18 19 ',
-    '    20 21 22 23 24 25 26 ',
-    '\x1b[1mMärz\x1b[0m27 28 29  1  2  3  4 ']
+    '\x1b[1m     Mo Di Mi Do Fr Sa So \x1b[0m',
+    '\x1b[1mDez. \x1b[0m28 29 30  1  2  3  4 ',
+    '      5  6  7  8  9 10 11 ',
+    '     \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
+    '     19 20 21 22 23 24 25 ',
+    '\x1b[1mJan. \x1b[0m26 27 28 29 30 31  1 ',
+    '      2  3  4  5  6  7  8 ',
+    '      9 10 11 12 13 14 15 ',
+    '     16 17 18 19 20 21 22 ',
+    '     23 24 25 26 27 28 29 ',
+    '\x1b[1mFeb. \x1b[0m30 31  1  2  3  4  5 ',
+    '      6  7  8  9 10 11 12 ',
+    '     13 14 15 16 17 18 19 ',
+    '     20 21 22 23 24 25 26 ',
+    '\x1b[1mMärz \x1b[0m27 28 29  1  2  3  4 ']
 
 example_de_netbsd = [
-    '\x1b[1m    Mo Di Mi Do Fr Sa So \x1b[0m',
-    '\x1b[1mDez.\x1b[0m28 29 30  1  2  3  4 ',
-    '     5  6  7  8  9 10 11 ',
-    '    \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
-    '    19 20 21 22 23 24 25 ',
-    '\x1b[1mJan.\x1b[0m26 27 28 29 30 31  1 ',
-    '     2  3  4  5  6  7  8 ',
-    '     9 10 11 12 13 14 15 ',
-    '    16 17 18 19 20 21 22 ',
-    '    23 24 25 26 27 28 29 ',
-    '\x1b[1mFeb.\x1b[0m30 31  1  2  3  4  5 ',
-    '     6  7  8  9 10 11 12 ',
-    '    13 14 15 16 17 18 19 ',
-    '    20 21 22 23 24 25 26 ',
-    '\x1b[1mM\xe4r.\x1b[0m27 28 29  1  2  3  4 ']
+    '\x1b[1m     Mo Di Mi Do Fr Sa So \x1b[0m',
+    '\x1b[1mDez. \x1b[0m28 29 30  1  2  3  4 ',
+    '      5  6  7  8  9 10 11 ',
+    '     \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
+    '     19 20 21 22 23 24 25 ',
+    '\x1b[1mJan. \x1b[0m26 27 28 29 30 31  1 ',
+    '      2  3  4  5  6  7  8 ',
+    '      9 10 11 12 13 14 15 ',
+    '     16 17 18 19 20 21 22 ',
+    '     23 24 25 26 27 28 29 ',
+    '\x1b[1mFeb. \x1b[0m30 31  1  2  3  4  5 ',
+    '      6  7  8  9 10 11 12 ',
+    '     13 14 15 16 17 18 19 ',
+    '     20 21 22 23 24 25 26 ',
+    '\x1b[1mM\xe4r. \x1b[0m27 28 29  1  2  3  4 ']
+
+example_fr = [
+    '\x1b[1m      lu ma me je ve sa di \x1b[0m',
+    '\x1b[1mdéc.  \x1b[0m28 29 30  1  2  3  4 ',
+    '       5  6  7  8  9 10 11 ',
+    '      \x1b[7m12\x1b[0m 13 14 15 16 17 18 ',
+    '      19 20 21 22 23 24 25 ',
+    '\x1b[1mjanv. \x1b[0m26 27 28 29 30 31  1 ',
+    '       2  3  4  5  6  7  8 ',
+    '       9 10 11 12 13 14 15 ',
+    '      16 17 18 19 20 21 22 ',
+    '      23 24 25 26 27 28 29 ',
+    '\x1b[1mfévr. \x1b[0m30 31  1  2  3  4  5 ',
+    '       6  7  8  9 10 11 12 ',
+    '      13 14 15 16 17 18 19 ',
+    '      20 21 22 23 24 25 26 ',
+    '\x1b[1mmars  \x1b[0m27 28 29  1  2  3  4 ']
 
 
 def test_vertical_month():
-    locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
-    vert_str = vertical_month(month=12, year=2011,
-                              today=datetime.date(2011, 12, 12))
-    assert vert_str == example1
+    try:
+        locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
+        vert_str = vertical_month(month=12, year=2011,
+                                  today=datetime.date(2011, 12, 12))
+        assert vert_str == example1
 
-    weno_str = vertical_month(month=12, year=2011,
-                              today=datetime.date(2011, 12, 12),
-                              weeknumber='right')
-    assert weno_str == example_weno
+        weno_str = vertical_month(month=12, year=2011,
+                                  today=datetime.date(2011, 12, 12),
+                                  weeknumber='right')
+        assert weno_str == example_weno
 
-    we_start_su_str = vertical_month(
-        month=12, year=2011,
-        today=datetime.date(2011, 12, 12),
-        firstweekday=6)
-    assert we_start_su_str == example_we_start_su
+        we_start_su_str = vertical_month(
+            month=12, year=2011,
+            today=datetime.date(2011, 12, 12),
+            firstweekday=6)
+        assert we_start_su_str == example_we_start_su
+    except locale.Error as error:
+        if str(error) == 'unsupported locale setting':
+            pytest.xfail(
+                'To get this test to run, you need to add `en_US.utf-8` to '
+                'your locales. On Debian GNU/Linux 8 you do this by '
+                'uncommenting `de_DE.utf-8 in /etc/locale.gen and then run '
+                '`locale-gen` (as root).'
+            )
+    finally:
+        locale.setlocale(locale.LC_ALL, 'C')
 
 
 def test_vertical_month_unicode():
@@ -197,7 +226,13 @@ def test_vertical_month_unicode():
                                   today=datetime.date(2011, 12, 12))
         # de_DE locale on at least Net and FreeBSD is different from the one
         # commonly used on linux systems
-        assert vert_str in [example_de, example_de_freebsd, example_de_netbsd]
+        if platform.system() == 'FreeBSD':
+            assert vert_str == example_de_freebsd
+        elif platform.system() == 'NetBSD':
+            assert vert_str == example_de_netbsd
+        else:
+            assert vert_str == example_de
+
         '\n'.join(vert_str)  # issue 142
     except locale.Error as error:
         if str(error) == 'unsupported locale setting':
@@ -209,11 +244,17 @@ def test_vertical_month_unicode():
             )
         else:
             raise
+    finally:
+        locale.setlocale(locale.LC_ALL, 'C')
 
 
 def test_vertical_month_unicode_weekdeays():
     try:
         locale.setlocale(locale.LC_ALL, 'cs_CZ.UTF-8')
+        vert_str = vertical_month(month=12, year=2011,
+                                  today=datetime.date(2011, 12, 12))
+        assert [line.lower() for line in vert_str] == [line.lower() for line in example_cz]
+        '\n'.join(vert_str)  # issue 142/293
     except locale.Error as error:
         if str(error) == 'unsupported locale setting':
             pytest.xfail(
@@ -224,11 +265,8 @@ def test_vertical_month_unicode_weekdeays():
             )
         else:
             raise
-
-    vert_str = vertical_month(month=12, year=2011,
-                              today=datetime.date(2011, 12, 12))
-    assert [line.lower() for line in vert_str] == [line.lower() for line in example_cz]
-    '\n'.join(vert_str)  # issue 142/293
+    finally:
+        locale.setlocale(locale.LC_ALL, 'C')
 
 
 def strip_accents(string):
@@ -257,3 +295,26 @@ def test_vertical_month_unicode_weekdeays_gr():
             )
         else:
             raise
+    finally:
+        locale.setlocale(locale.LC_ALL, 'C')
+
+
+def test_vertical_month_abbr_fr():
+    # see issue #653
+    try:
+        locale.setlocale(locale.LC_ALL, 'fr_FR.UTF-8')
+        vert_str = vertical_month(month=12, year=2011,
+                                  today=datetime.date(2011, 12, 12))
+        assert '\n'.join(vert_str) == '\n'.join(example_fr)
+    except locale.Error as error:
+        if str(error) == 'unsupported locale setting':
+            pytest.xfail(
+                'To get this test to run, you need to add `fr_FR.UTF-8` to '
+                'your locales. On Debian GNU/Linux 8 you do this by '
+                'uncommenting `fr_FR.UTF-8` in /etc/locale.gen and then run '
+                '`locale-gen` (as root).'
+            )
+        else:
+            raise
+    finally:
+        locale.setlocale(locale.LC_ALL, 'C')
