@@ -373,6 +373,8 @@ def test_printformats(runner):
     assert not result.exception
 
 
+# "see #810"
+@pytest.mark.xfail
 def test_repeating(runner):
     runner = runner(default_command='list', days=2)
     now = datetime.datetime.now().strftime('%d.%m.%Y')
@@ -651,8 +653,10 @@ def test_print_ics_command(runner):
     # Non existing file
     result = runner.invoke(main_khal, ['printics', 'nonexisting_file'])
     assert result.exception
-    assert 'Error: Invalid value for "ics": Could not open file: ' \
-        in result.output
+    assert ('Error: Invalid value for "ics": Could not open file: ' \
+        in result.output or \
+            'Error: Invalid value for "[ICS]": Could not open file:' \
+            in result.output)
 
     # Run on test files
     result = runner.invoke(main_khal, ['printics', _get_ics_filepath('cal_d')])
@@ -681,7 +685,7 @@ def test_printics_read_from_stdin(runner):
     runner = runner(command='printics')
     result = runner.invoke(main_khal, ['printics'], input=_get_text('cal_d'))
     assert not result.exception
-    assert result.output == '1 events found in stdin input\n An Event\n'
+    assert '1 events found in stdin input\n An Event\n' in result.output
 
 
 def test_configure_command_config_exists(runner):
